@@ -31,11 +31,27 @@ class pyIDI:
     The pyIDI base class represents the video to be analysed.
     """
     def __init__(self, cih_file):
-        self.cih_file = cih_file
+        
         if type(cih_file) == str:
+            self.cih_file = cih_file
             self.root = os.path.split(self.cih_file)[0]
-        else:
+            # Load selected video
+            self.mraw, self.info = pyMRAW.load_video(self.cih_file)
+            self.N = self.info['Total Frame']
+            self.image_width = self.info['Image Width']
+            self.image_height = self.info['Image Height']
+
+        elif type(cih_file) in [np.ndarray, np.memmap]:
             self.root = ''
+            self.mraw = cih_file
+            self.cih_file = 'ndarray_video.cih'
+            self.N = cih_file.shape[0]
+            self.image_height = cih_file.shape[1]
+            self.image_width = cih_file.shape[2]
+            self.info = {}
+
+        else:
+            raise ValueError('`cih_file` must be either a cih filename or a 3D array (N_time, height, width)')
 
         self.available_methods = dict([ 
             (key, {
@@ -50,24 +66,8 @@ class pyIDI:
             f"'{key}' ({method_dict['IDIMethod'].__name__}): {method_dict['description']}"
             for key, method_dict in self.available_methods.items()
             ])
-        tools.update_docstring(self.set_method, added_doc=available_methods_doc)
+        tools.update_docstring(self.set_method, added_doc=available_methods_doc)  
 
-        if type(cih_file) == str:
-            # Load selected video
-            self.mraw, self.info = pyMRAW.load_video(self.cih_file)
-            self.N = self.info['Total Frame']
-            self.image_width = self.info['Image Width']
-            self.image_height = self.info['Image Height']
-        
-        elif type(cih_file) == np.ndarray:
-            self.mraw = cih_file
-            self.N = cih_file.shape[0]
-            self.image_height = cih_file.shape[1]
-            self.image_width = cih_file.shape[2]
-            self.info = {}
-        
-        else:
-            raise ValueError('`cih_file` must be either a cih filename or a 3D array (N_time, height, width)')
 
 
     def set_method(self, method, **kwargs):
@@ -204,7 +204,10 @@ class pyIDI:
     
 
     def create_analysis_directory(self):
-        cih_file_ = os.path.split(self.cih_file)[-1].split('.')[0]
+        if type(self.cih_file) == str:
+            cih_file_ = os.path.split(self.cih_file)[-1].split('.')[0]
+        else:
+            cih_file_ = 'ndarary_video'
         self.root_analysis = os.path.join(self.root, f'{cih_file_}_pyidi_analysis')
         if not os.path.exists(self.root_analysis):
             os.mkdir(self.root_analysis)
